==> haskell-yesod-test-1.6.23-123-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-test
version:              1.6.23
visibility:           public
id:                   yesod-test-1.6.23-6vs8MdYkMkc1BeBxKAtQsl
key:                  yesod-test-1.6.23-6vs8MdYkMkc1BeBxKAtQsl
license:              MIT
maintainer:           Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author:               Nubis <nubis@woobiz.com.ar>
stability:            Experimental
homepage:             http://www.yesodweb.com
synopsis:             integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>

category:             Web, Yesod, Testing
abi:                  0ebe64833931ab6ddb4e633bd60b2e55
exposed:              True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.Internal
    Yesod.Test.Internal.SIO Yesod.Test.TransversingCSS

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-test-1.6.23
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-test-1.6.23
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-test-1.6.23
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-test
hs-libraries:         HSyesod-test-1.6.23-6vs8MdYkMkc1BeBxKAtQsl
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv
    blaze-html-0.9.2.0-5pCa6Zd2ytCBxKPCiAVcIx
    blaze-markup-0.8.3.0-JJ5r8tycCxXJkM0kXa0ha9 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    hspec-core-2.11.4-LH4ljAyFr7833CkU966kHA
    html-conduit-1.3.2.2-7OteWGabFNf1YJd3eMqlmA
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR process-1.6.19.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0 wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
    wai-extra-3.1.18-1ANzYYqVephHj2C1lo6Zwk
    xml-conduit-1.9.1.4-AWUHrHEyod1C1UJeqVfDQt
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    yesod-core-1.6.27.1-KtBa6Xls8994lQw12Q4B1F

haddock-interfaces:   /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html:         /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-test-1.6.23-125-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-test
version:              1.6.23
visibility:           public
id:                   yesod-test-1.6.23-8slwnHoUEeGChe9YChHvvL
key:                  yesod-test-1.6.23-8slwnHoUEeGChe9YChHvvL
license:              MIT
maintainer:           Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author:               Nubis <nubis@woobiz.com.ar>
stability:            Experimental
homepage:             http://www.yesodweb.com
synopsis:             integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>

category:             Web, Yesod, Testing
abi:                  ea0e4934b7e614e294249258de7ff240
exposed:              True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.Internal
    Yesod.Test.Internal.SIO Yesod.Test.TransversingCSS

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-test-1.6.23
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-test-1.6.23
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-test-1.6.23
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-test
hs-libraries:         HSyesod-test-1.6.23-8slwnHoUEeGChe9YChHvvL
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH
    attoparsec-0.14.4-8hLS1m777hPFjiaInp95BL base-4.18.2.1
    blaze-builder-0.4.4.1-Hto81bisFYkHXSmpZG8kx7
    blaze-html-0.9.2.0-AqjQr4Ps51QD51ybemU3ZY
    blaze-markup-0.8.3.0-K7wUMOM5SyIFeEdepQMdjc bytestring-0.11.5.3
    case-insensitive-1.2.1.0-8PStX6cixKCLkUJoPuARL
    conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    hspec-core-2.11.4-K7WhEYoVaEl4ISGwW2E5jD
    html-conduit-1.3.2.2-C2pIyvMhdI89YxzeT9ZQDA
    http-types-0.12.4-2YF0olXF9itCctWavExzmH
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-3.1.4.0-xB4epdb1XO3ZKzAxljM4X
    pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR process-1.6.19.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0 wai-3.2.4-BLc210LwMQhDvJHRqgIjev
    wai-extra-3.1.18-2NqKPuFl5Jd2v0if4D3Rrq
    xml-conduit-1.9.1.4-6YUKnRkiQ5NBAoTmcKCArn
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    yesod-core-1.6.27.1-4gpTrKJARZw1tOAQMfFW4B

haddock-interfaces:   /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html:         /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
